Header menu logo ArrayT

DebugIndexer<'T> Type

A simple Wrapper for an array. The sole purpose is to provide a better Exception message when an index is out of range.

Constructors

Constructor Description

DebugIndexer(arr)

Full Usage: DebugIndexer(arr)

Parameters:
    arr : 'T[]

Returns: DebugIndexer<'T>
arr : 'T[]
Returns: DebugIndexer<'T>

Instance members

Instance member Description

this.Array

Full Usage: this.Array

Returns: 'T[]

Gets the wrapped array.

Returns: 'T[]

this[i]

Full Usage: this[i]

Returns: int
Gets or sets an item at the specified index with descriptive error messages.
 Index parameter: the index to access or set.
 Set value parameter: the value to set (setter only).
Returns: int

this.Length

Full Usage: this.Length

Returns: int

Gets the length of the wrapped array.

Returns: int

Type something to start searching.