DebugIndexer<'T> Type
A simple Wrapper for an array. The sole purpose is to provide a better Exception message when an index is out of range.
Constructors
| Constructor |
Description
|
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.Array
Returns: 'T[]
|
Gets the wrapped array.
|
Full Usage:
this[i]
Returns: int
|
Gets or sets an item at the specified index with descriptive error messages. Index parameter: the index to access or set. Set value parameter: the value to set (setter only).
|
Full Usage:
this.Length
Returns: int
|
Gets the length of the wrapped array.
|
ArrayT